==> flyspray_0.9.7.orig.tar.gz: flyspray-0.9.7/lang/en/register.php <==
<?php

global $register_text;
$register_text = array (

'registernewuser'	=>	'Register new user',
'requiredfields'	=>	'Required fields are marked with a',
'username'		=>	'Username',
'password'		=>	'Password',
'confirmpass'		=>	'Confirm Password',
'realname'		=>	'Real Name',
'emailaddress'		=>	'Email Address',
'jabberid'		=>	'Jabber ID',
'notifications'		=>	'Notifications',
'none'			=>	'None',
'email'			=>	'Email',
'jabber'		=>	'Jabber',
'note'			=>	'<b>Note:</b>  You will be sent a confirmation code before your account is created.  The code will be sent using your preferred notification method, above.<br>IF YOU ENTER FAKE DETAILS, YOU WILL NOT RECEIVE YOUR CODE.',
'sendcode'		=>	'Send code!',
'entercode'             =>      'Enter the confirmation code you received in your notification message.  Also enter your desired account password.',  // Changed in 0.9.7
'confirmationcode'	=>      'Confirmation Code',
'registeraccount'	=>      'Register this account',
'registererror'		=>      'Ensure that you have filled in all required fields, and that you have entered correct details for your desired notification type.',
'usernametaken'		=>      'That username is already taken.  You will need to choose another one.',
'goback'                =>      'Go back and do it.',
'noticefrom'		=>      'Notice from',
'addressused'		=>      'This address has been used to register a Flyspray account.  If you were not expecting this message, please ignore and delete it.  Your confirmation code is:',

// Added in version 0.9.7
'badmagic'              =>      'That is not a valid magic key! Are you sure that you got that from your notification message?',

);
?>

==> flyspray_0.9.8.orig.tar.gz: flyspray-0.9.8/lang/en/register.php <==
<?php

global $register_text;
$register_text = array (

'registernewuser'	=>	'Register new user',
'requiredfields'	=>	'Required fields are marked with a',
'username'		=>	'Username',
'password'		=>	'Password',
'confirmpass'		=>	'Confirm Password',
'realname'		=>	'Real Name',
'emailaddress'		=>	'Email Address',
'jabberid'		=>	'Jabber ID',
'notifications'		=>	'Notifications',
'none'			=>	'None',
'email'			=>	'Email',
'jabber'		=>	'Jabber',
'note'			=>	'<b>Note:</b>  You will be sent a confirmation code before your account is created.  The code will be sent using your preferred notification method, above.<br />IF YOU ENTER FAKE DETAILS, YOU WILL NOT RECEIVE YOUR CODE.',
'sendcode'		=>	'Send code!',
'entercode'             =>      'Enter the confirmation code you received in your notification message.  Also enter your desired account password.',  // Changed in 0.9.7
'confirmationcode'	=>      'Confirmation Code',
'registeraccount'	=>      'Register this account',
'registererror'		=>      'Ensure that you have filled in all required fields, and that you have entered correct details for your desired notification type.',
'usernametaken'		=>      'That username is already taken.  You will need to choose another one.',
'goback'                =>      'Go back and do it.',
'noticefrom'		=>      'Notice from',
'addressused'		=>      'This address has been used to register a Flyspray account.  If you were not expecting this message, please ignore and delete it.  Your confirmation code is:',

// Added in version 0.9.7
'badmagic'              =>      'That is not a valid magic key! Are you sure that you got that from your notification message?',

);
?>
